package cz.frantovo.hrisniciSpameri.dao;

import cz.frantovo.hrisniciSpameri.dto.Cil;
import cz.frantovo.hrisniciSpameri.dto.SitovaAdresa;
import cz.frantovo.hrisniciSpameri.dto.Souhrn;
import java.sql.Connection;
import java.sql.Date;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.Collection;
import java.util.logging.Level;

/**
 *
 * @author fiki
 */
public class SouhrnDAO extends HrisniciSuperDAO {

    private enum SQL {

        DENNI_SOUHRN,
        DENNI_SOUHRN_CIL,
        SOUHRN_ZA_OBDOBI,
        SOUHRN_ZA_OBDOBI_CIL
    }

    /**
     * Získá z databáze souhrn útoků. Buď pro konkrétní den nebo pro dané období.
     * @param zacatek začátek období nebo konkrétní den
     * @param konec konec období nebo null (pokud nás zajímá konkrétní den)
     * @param cil id cíle nebo nula, pokud chceme všechny cíle
     * @return seznam útoků
     */
    public Collection<Souhrn> getSouhrn(Date zacatek, Date konec, int cil) {
        Collection<Souhrn> souhrn = new ArrayList<Souhrn>();

        Connection db = getSpojeni(null);
        if (db == null) {
            return null;
        } else {
            PreparedStatement ps = null;
            ResultSet rs = null;
            try {
                if (konec == null) {
                    if (cil == 0) {
                        ps = db.prepareStatement(getSQL(SQL.DENNI_SOUHRN));
                        ps.setDate(1, zacatek);
                    } else {
                        ps = db.prepareStatement(getSQL(SQL.DENNI_SOUHRN_CIL));
                        ps.setDate(1, zacatek);
                        ps.setInt(2, cil);
                    }
                } else {
                    if (cil == 0) {
                        ps = db.prepareStatement(getSQL(SQL.SOUHRN_ZA_OBDOBI));
                        ps.setDate(1, zacatek);
                        ps.setDate(2, konec);
                    } else {
                        ps = db.prepareStatement(getSQL(SQL.SOUHRN_ZA_OBDOBI_CIL));
                        ps.setDate(1, zacatek);
                        ps.setDate(2, konec);
                        ps.setInt(3, cil);
                    }
                }


                rs = ps.executeQuery();
                while (rs.next()) {
                    Souhrn s = new Souhrn();
                    s.setAdresa(new SitovaAdresa(rs.getString("ip"), rs.getString("domena")));
                    s.setDen(rs.getDate("den"));
                    s.setPocet(rs.getInt("pocet"));

                    Cil c = new Cil();
                    c.setId(rs.getInt("id"));
                    c.setNazev(rs.getString("nazev"));
                    c.setUrl(rs.getString("url"));
                    c.setSelekt(rs.getString("selekt"));
                    c.setDatabaze(rs.getString("databaze"));
                    s.setCil(c);

                    souhrn.add(s);
                }
            } catch (Exception e) {
                log.log(Level.SEVERE, "Chyba při získávání souhrnu z databáze", e);
            } finally {
                zavri(db, ps, rs);
            }
        }

        return souhrn;
    }
}
